@@ -1,5 +1,5 @@
 
-from cloud_governance.common.es.es_operations import ESOperations
+from cloud_governance.common.elasticsearch.elasticsearch_operations import ElasticSearchOperations
 from cloud_governance.common.logger.logger_time_stamp import logger_time_stamp
 
 
@@ -24,9 +24,9 @@ class ESUploader:
         """
         This method upload data to input ELK
         """
-        es_operations = ESOperations(es_host=self.__es_host, es_port=self.__es_port, region=self.__region_name, bucket=self.__bucket_name, logs_bucket_key=self.__logs_bucket_key)
+        es_operations = ElasticSearchOperations(es_host=self.__es_host, es_port=self.__es_port, region=self.__region_name, bucket=self.__bucket_name, logs_bucket_key=self.__logs_bucket_key)
         self.__es_add_items.update({'policy': self.__policy_name, 'region': self.__region_name})
-        es_operations.upload_last_policy_to_es(policy=self.__policy_name, index=self.__es_index, doc_type=self.__es_doc_type, s3_json_file=self.__s3_file_name,
-                                               es_add_items=self.__es_add_items)
+        es_operations.upload_last_policy_to_elasticsearch(policy=self.__policy_name, index=self.__es_index, doc_type=self.__es_doc_type, s3_json_file=self.__s3_file_name,
+                                                          es_add_items=self.__es_add_items)
 
 
