@@ -38,7 +38,7 @@ from cloud_governance.aws.zombie_non_cluster.zombie_non_cluster_polices import Z
 # os.environ['resource'] = 'zombie_cluster_nat_gateway'
 # os.environ['cluster_tag'] = ''
 # os.environ['cluster_tag'] = ''
-# os.environ['policy_output'] = 's3://redhat-cloud-governance/logs'
+# os.environ['policy_output'] = 's3://bucket_name/logs'
 # os.environ['policy_output'] = os.path.dirname(os.path.realpath(__file__))
 # os.environ['policy'] = 'ebs_unattached'
 # os.environ['resource_name'] = 'ocp-test'
@@ -246,7 +246,7 @@ def main():
     es_doc_type = os.environ.get('es_doc_type', '')
     bucket = os.environ.get('bucket', '')
 
-    zombie_non_cluster_polices = ['ec2_idle', 'ec2_stop', 'empty_buckets', 'empty_roles', 'zombie_elastic_ips', 'zombie_nat_gateways', 'zombie_snapshots']
+    zombie_non_cluster_polices = ['ec2_idle', 'ec2_stop', 'ebs_unattached', 'empty_buckets', 'empty_roles', 'zombie_elastic_ips', 'zombie_nat_gateways', 'zombie_snapshots']
     zombie_non_cluster_polices_runner = None
     is_zombie_non_cluster_polices_runner = policy in zombie_non_cluster_polices
     if is_zombie_non_cluster_polices_runner:
